@@ -2,6 +2,12 @@ from collections import OrderedDict
 
 import numpy as np
 
+import matplotlib as mpl
+import matplotlib.cbook as cbook
+if tuple(int(_) for _ in mpl.__version__.split('.'))[:2] >= (3, 4):
+    from matplotlib._api import check_in_list
+else:
+    from matplotlib.cbook import _check_in_list as check_in_list
 from matplotlib.axes import Axes
 import matplotlib.lines as mlines
 import matplotlib.patches as mpatches
@@ -11,7 +17,6 @@ from mpltern.ternary.spines import Spine
 from mpltern.ternary.transforms import (
     TernaryTransform, TernaryPerpendicularTransform,
     BarycentricTransform, TernaryScaleTransform, TernaryShift)
-from mpltern import cbook
 from mpltern.ternary.axis import TAxis, LAxis, RAxis
 from mpltern.ternary.ternary_parser import (
     _parse_ternary_single, _parse_ternary_multiple,
@@ -44,8 +49,16 @@ def _create_corners(corners=None, rotation=None):
 
 
 class TernaryAxesBase(Axes):
+    _axis_names = ("x", "y", "t", "l", "r")
+    _shared_axes = {name: cbook.Grouper() for name in _axis_names}
+
     def __init__(self, *args, ternary_scale=1.0, corners=None, rotation=None,
                  **kwargs):
+        # workaround for matplotlib>=3.6.0
+        self._sharet = None
+        self._sharel = None
+        self._sharer = None
+
         # Triangle corners in the original data coordinates
         self.corners_data = _create_corners(corners, rotation)
         sx = np.sqrt(3.0) * 0.5  # Scale for x
@@ -61,6 +74,18 @@ class TernaryAxesBase(Axes):
         self.set_ternary_lim(
             0.0, ternary_scale, 0.0, ternary_scale, 0.0, ternary_scale)
 
+    @property
+    def callbacks(self):
+        if tuple(int(_) for _ in mpl.__version__.split('.'))[:2] < (3, 6):
+            return cbook.CallbackRegistry()
+        else:
+            return cbook.CallbackRegistry(
+               signals=[f"{name}lim_changed" for name in self._axis_names])
+
+    @callbacks.setter
+    def callbacks(self, value):
+        pass
+
     def set_figure(self, fig):
         self.viewTLim = mtransforms.Bbox.unit()
         self.viewLLim = mtransforms.Bbox.unit()
@@ -68,7 +93,7 @@ class TernaryAxesBase(Axes):
         super().set_figure(fig)
 
     def _get_axis_list(self):
-        return (self.taxis, self.laxis, self.raxis)
+        return tuple(getattr(self, f"{name}axis") for name in self._axis_names)
 
     def _get_axis_map(self):
         # workaround for matplotlib>=3.4.0
@@ -211,16 +236,25 @@ class TernaryAxesBase(Axes):
         """Return the RAxis instance"""
         return self.raxis
 
-    def cla(self):
+    def clear(self):
         self.set_tlim(0.0, self.ternary_scale)
         self.set_llim(0.0, self.ternary_scale)
         self.set_rlim(0.0, self.ternary_scale)
-        super().cla()
+        if tuple(int(_) for _ in mpl.__version__.split('.'))[:2] < (3, 6):
+            super().cla()
+        else:
+            super().clear()
         xmin = -1.0 / np.sqrt(3.0)
         xmax = +1.0 / np.sqrt(3.0)
         self.set_xlim(xmin, xmax)
         self.set_ylim(0.0, 1.0)
 
+    if tuple(int(_) for _ in mpl.__version__.split('.'))[:2] < (3, 6):
+        cla = clear
+
+    def autoscale_view(self, *args, **kwargs):
+        pass
+
     def grid(self, b=None, which='major', axis='both', **kwargs):
         """
         Configure the grid lines.
@@ -259,7 +293,7 @@ class TernaryAxesBase(Axes):
         """
         if len(kwargs):
             b = True
-        cbook._check_in_list(['t', 'l', 'r', 'both'], axis=axis)
+        check_in_list(['t', 'l', 'r', 'both'], axis=axis)
         if axis in ['t', 'both']:
             self.taxis.grid(b, which=which, **kwargs)
         if axis in ['l', 'both']:
@@ -268,7 +302,7 @@ class TernaryAxesBase(Axes):
             self.raxis.grid(b, which=which, **kwargs)
 
     def tick_params(self, axis='both', **kwargs):
-        cbook._check_in_list(['t', 'l', 'r', 'both'], axis=axis)
+        check_in_list(['t', 'l', 'r', 'both'], axis=axis)
         if axis in ['t', 'both']:
             bkw = dict(kwargs)
             bkw.pop('left', None)
@@ -396,13 +430,9 @@ class TernaryAxesBase(Axes):
         self._set_ternary_lim_from_xlim_and_ylim()
 
     def get_children(self):
-        from matplotlib import __version__ as mversion
         children = super().get_children()
-        major, minor, patch = [int(_) for _ in mversion.split('.')]
-        if (major, minor) <= (3, 0):
-            children.remove(self.xaxis)
-            children.remove(self.yaxis)
-            children.extend(self._get_axis_list())
+        children.remove(self.xaxis)
+        children.remove(self.yaxis)
         return children
 
     def _set_ternary_lim_from_xlim_and_ylim(self):
